AC_DEFUN([WITH_OPENJDK_SRC_ZIP],
[
  AC_MSG_CHECKING(openjdk source zip)
  AC_ARG_WITH([openjdk-src-zip],
              [AS_HELP_STRING(--with-openjdk-src-zip,specify the location of the openjdk source zip)],
  [
    OPENJDK_SRC_ZIP=${withval}
    AM_CONDITIONAL(USE_OPENJDK_SRC_ZIP, test x = x)
  ],
  [ 
    OPENJDK_SRC_ZIP="not specified"
    AM_CONDITIONAL(USE_OPENJDK_SRC_ZIP, test x != x)
  ])
  AC_MSG_RESULT(${OPENJDK_SRC_ZIP})
  AC_SUBST(OPENJDK_SRC_ZIP)
])

AC_DEFUN([WITH_CLASSPATH_SRC_ZIP],
[
  AC_MSG_CHECKING(classpath source zip)
  AC_ARG_WITH([classpath-src-zip],
              [AS_HELP_STRING(--with-classpath-src-zip,specify the location of the classpath source zip)],
  [
    CLASSPATH_SRC_ZIP=${withval}
    AM_CONDITIONAL(USE_CLASSPATH_SRC_ZIP, test x = x)
  ],
  [ 
    CLASSPATH_SRC_ZIP="not specified"
    AM_CONDITIONAL(USE_CLASSPATH_SRC_ZIP, test x != x)
  ])
  AC_MSG_RESULT(${CLASSPATH_SRC_ZIP})
  AC_SUBST(CLASSPATH_SRC_ZIP)
])

AC_DEFUN([WITH_CLASSPATH_GLIBJ_ZIP],
[
  AC_MSG_CHECKING(GNU Classpath classes)
  AC_ARG_WITH([classpath-jar],
              [AS_HELP_STRING(--with-classpath-jar,specify the location of Classpath's class files)],
  [
    CLASSPATH_GLIBJ_ZIP=${withval}
    AM_CONDITIONAL(USE_CLASSPATH_GLIBJ_ZIP, test x = x)
  ],
  [ 
    CLASSPATH_SRC_ZIP="not specified"
    AM_CONDITIONAL(USE_CLASSPATH_GLIBJ_ZIP, test x != x)
  ])
  AC_MSG_RESULT(${CLASSPATH_GLIBJ_ZIP})
  AC_SUBST(CLASSPATH_GLIBJ_ZIP)
])

AC_DEFUN([FIND_TOOL],
[AC_PATH_TOOL([$1],[$2])
 if test x"$$1" = x ; then
   AC_MSG_ERROR([$2 program not found in PATH])
 fi
 AC_SUBST([$1])
])

AC_DEFUN([GET_CLASSPATH],
[if ! test -d classpath ; then
 AC_MSG_NOTICE([Checking out Classpath sources])
 ${CVS} -q -z3 -d:pserver:anonymous@cvs.savannah.gnu.org:/sources/classpath \
	co classpath &> /dev/null
 cd classpath
 ./autogen.sh &> /dev/null
 cd ..
fi
])

AC_DEFUN([GET_JAXWS],
[if ! test -d jaxws ; then
 AC_MSG_NOTICE([Checking out JAXWS sources])
 ${HG} clone http://hg.openjdk.java.net/jdk7/jdk7/jaxws &> /dev/null
fi
])

AC_DEFUN([INSTALL_JAXWS],
[if ! test -d classpath/external/jaxws ; then
 AC_MSG_NOTICE([Installing JAXWS in external])
 mkdir classpath/external/jaxws
 mv jaxws/src/share/classes/com jaxws/src/share/classes/javax classpath/external/jaxws
 mv jaxws/src/share/classes/META-INF/* classpath/resource/META-INF
 mv classpath/external/jaxws/com/sun/tools/etc/META-INF/services/com.sun.mirror.apt.AnnotationProcessorFactory classpath/resource/META-INF/services
fi
])

AC_DEFUN([GET_JDK],
[if ! test -d jdk ; then
 AC_MSG_NOTICE([Checking out JDK sources])
 ${HG} clone http://hg.openjdk.java.net/jdk7/jdk7/jdk &> /dev/null
fi
])

AC_DEFUN([INSTALL_JDK],
[if ! test -f classpath/java/util/Scanner.java ; then
 AC_MSG_NOTICE([Installing elements of OpenJDK])
 mv jdk/src/share/classes/java/util/Scanner.java classpath/java/util
 mv jdk/src/share/classes/sun/misc/LRUCache.java classpath/sun/misc
fi
])

AC_DEFUN([PATCH_CLASSPATH],
[
 AC_MSG_NOTICE([Patching Classpath])
 cd classpath
 for p in ../patches/brandweg-jaxws-build.patch \
	../patches/brandweg-jaxws-dist.patch ; 
 do 
   AC_MSG_NOTICE([Checking $p])
   if ${PATCH} -l -p0 --dry-run -s -t -f -F 0 < $p ; then 
     AC_MSG_NOTICE([Applying $p])
     ${PATCH} -l -p0 < $p
   fi
 done
 cd ..
])
